/*
  ISC License

  Copyright (c) 2021, Antonio SJ Musumeci <trapexit@spawn.link>

  Permission to use, copy, modify, and/or distribute this software for any
  purpose with or without fee is hereby granted, provided that the above
  copyright notice and this permission notice appear in all copies.

  THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES
  WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF
  MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR
  ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES
  WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN
  ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF
  OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.
*/

#ifndef CRC32B_H_INCLUDED
#define CRC32B_H_INCLUDED

#ifdef __cplusplus
extern "C"
{
#endif

typedef unsigned int crc32b_t;

crc32b_t crc32b_start(void);
crc32b_t crc32b_continue(const void     *buf,
                         const crc32b_t  len,
                         const crc32b_t  crc);
crc32b_t crc32b_finish(const crc32b_t crc);

crc32b_t crc32b(const void *buf, crc32b_t len);

#ifdef __cplusplus
}
#endif

#endif
